@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 #use warnings;
 
-our $VERSION = '0.5402';
+our $VERSION = '0.5403';
 
 use Carp;
 use Math::BigInt;
@@ -333,7 +333,7 @@ sub del_set {
 
 # This method works almost like the new method except that it takes an
 # object as an argement and will modify it instead of creating a new
-# object, also any tags assosated with the object are left in tact
+# object, also any tags associated with the object are left in tact
 # unless a new tag is given to override the old.
 sub modify {
   my $me = shift;
@@ -863,7 +863,7 @@ Math::FractionManip - Manipulate fractions
 
 =head1 VERSION
 
-version 0.5402
+version 0.5403
 
 =head1 SYNOPSIS
 
@@ -1252,6 +1252,10 @@ turn it off.
 
 The F<t/01-methods.t> program in this distribution
 
+=head1 MAINTAINER
+
+Gene Boggs <gene@cpan.org>
+
 =head1 AUTHOR
 
 Kevin Atkinson <kevina@clark.net>
